@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001, 2002, 2003, 2004 Philip Blundell <philb@gnu.org>
- *               2004, 2005 Florian Boor <florian@kernelconcepts.de>
+ *               2004, 2005, 2006 Florian Boor <florian@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -9,7 +9,7 @@
  */
 
 /*
- * $Id: main.c,v 1.126 2006/02/03 13:05:28 florian Exp $
+ * $Id: main.c 8707 2006-08-05 00:22:06Z florian $
  *
  */
 
@@ -397,12 +397,12 @@ build_children (GtkWidget *vbox, GSList *children, struct contacts_person *p)
                 if (year)
                   { 
                     tm.tm_year = year - 1900;
-                    tm.tm_mon = month;
+                    tm.tm_mon = month - 1;
                     tm.tm_mday = day;
                     strftime(buf, sizeof(buf), "%x", &tm);
                   }
                 else 
-                  snprintf(buf,sizeof(buf),"%02d/%02d", month+1, day);
+                  snprintf(buf,sizeof(buf),"%02d/%02d", month, day);
                 w = gtk_label_new(buf);
                 gtk_misc_set_alignment(GTK_MISC(w), 0.0, 0.5);
                 hbox = gtk_hbox_new(FALSE, gpe_get_boxspacing());
@@ -455,6 +455,39 @@ build_children (GtkWidget *vbox, GSList *children, struct contacts_person *p)
   return result;
 }
 
+static GArray *
+build_categories_color_array (struct contacts_person *p)
+{
+  GArray *result = NULL;
+  GSList *iter, *categories;
+  
+  categories = get_categories_list (p);
+  
+  for (iter = categories; iter; iter = iter->next)
+    {
+      const gchar *col;
+      col = gpe_pim_category_colour ((gint)iter->data);
+
+      if (col)
+        {
+			GdkColor color;
+			if (!result)
+				result = g_array_new (TRUE, TRUE, sizeof (GdkColor));
+			if (gdk_color_parse (col, &color) 
+				&& gdk_colormap_alloc_color (gdk_colormap_get_system (),
+                                             &color, FALSE, TRUE ))
+			  {
+				  g_array_append_val (result, color);
+			  }
+	    }
+    }
+    
+  if (categories)
+    g_slist_free (categories);
+  
+  return result;
+}
+
 static int
 show_details (struct contacts_person *p)
 {
@@ -468,9 +501,35 @@ show_details (struct contacts_person *p)
   GSList *page;
   GtkWidget *label;
   gchar *text;
+  GtkWidget *cat_display = g_object_get_data (G_OBJECT(mainw), "cat_display");
 
   table = GTK_TABLE (lookup_widget (mainw, "tabDetail"));
   
+  /* show categories colours */
+  if ((p != NULL) && (cat_display))
+    {
+      GArray *catcolours = build_categories_color_array(p);
+      GArray *c_old = g_object_get_data (G_OBJECT (cat_display), "catcolours");
+      if (catcolours)
+        {
+        
+          if (c_old)
+            g_array_free (c_old, TRUE);
+        
+          g_object_set_data (G_OBJECT (cat_display), "catcolours", catcolours);
+          gtk_widget_show (cat_display);
+          gtk_widget_queue_draw (cat_display);
+        }
+      else
+        {
+          g_object_set_data (G_OBJECT (cat_display), "catcolours", NULL);
+          if (c_old)
+            g_array_free (c_old, TRUE);
+          gtk_widget_set_size_request (cat_display, 0, -1);
+          gtk_widget_hide (cat_display);
+        }
+    }
+    
   if (mode_landscape) /* we show all available data */
     {
       wlist = gtk_container_get_children (GTK_CONTAINER (table));
@@ -484,8 +543,8 @@ show_details (struct contacts_person *p)
       i = 1;
       if (p != NULL) /* add contact data */
         {
-          GtkWidget *vbox = gtk_vbox_new(FALSE, gpe_get_boxspacing());
           gchar *catstring = build_categories_string(p);
+          GtkWidget *vbox = gtk_vbox_new(FALSE, gpe_get_boxspacing());
         
           gtk_table_attach(GTK_TABLE(table), vbox, 0, 1, 0, 1, 
                            GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 0, 0);
@@ -649,11 +708,13 @@ selection_made (GtkTreeSelection *sel, GObject *o)
   struct contacts_person *p;
   GtkTreeModel *model;
   GtkWidget *edit_button, *delete_button, *new_button, *details_button;
+  GtkWidget *cat_display;
 
   edit_button = g_object_get_data (o, "edit-button");
   delete_button = g_object_get_data (o, "delete-button");
   new_button = g_object_get_data (o, "new-button");
   details_button = g_object_get_data (o, "details-button");
+  cat_display = g_object_get_data (G_OBJECT(mainw), "cat_display");
   
   if (gtk_tree_selection_get_selected (sel, &model, &iter))
     {
@@ -667,6 +728,7 @@ selection_made (GtkTreeSelection *sel, GObject *o)
       gtk_widget_set_sensitive (delete_button, TRUE);
       if (!mode_landscape)
         gtk_widget_set_sensitive (details_button, TRUE);
+      gtk_widget_show (cat_display);
     }
   else
     {
@@ -674,6 +736,7 @@ selection_made (GtkTreeSelection *sel, GObject *o)
       gtk_widget_set_sensitive (delete_button, FALSE);
       if (!mode_landscape)
         gtk_widget_set_sensitive (details_button, FALSE);
+      gtk_widget_hide (cat_display);
     }
 	/* restore after edit/new */
     gtk_widget_set_sensitive (new_button, TRUE);
@@ -916,9 +979,9 @@ void
 list_view_cursor_changed (GtkTreeView *treeview, gpointer user_data)
 {
   GtkWidget *lStatus = user_data;
-  int pos;
-  int count =
-      gtk_tree_model_iter_n_children(GTK_TREE_MODEL(list_store), NULL);
+  gint pos;
+  gint count =
+       gtk_tree_model_iter_n_children(GTK_TREE_MODEL(list_store), NULL);
   GtkTreePath *path;
   
   if (lStatus)
@@ -1148,6 +1211,36 @@ list_button_release_event (GtkWidget *widget, GdkEventButton *b, GtkListStore *l
   return FALSE;
 }
 
+gboolean
+cat_display_expose (GtkWidget *cat_display, GdkEventExpose *event, gpointer data)
+{
+  GArray *catcolours = g_object_get_data (G_OBJECT (cat_display), "catcolours");
+  GtkWidget *framelabel = g_object_get_data (G_OBJECT (cat_display), "label");
+  gint i;
+  gint height = 1;
+
+  if (!catcolours)
+    return FALSE;
+  
+  height = framelabel->allocation.height;
+  
+  gtk_widget_set_size_request (cat_display, 
+                               height * catcolours->len + 3, height);
+
+  for (i = 0; i < catcolours->len; i++)
+    {
+      static GdkColor color;
+      GdkGC *gc = gdk_gc_new (GDK_DRAWABLE (cat_display->window));
+      color = g_array_index (catcolours, GdkColor, i);
+      gdk_gc_set_foreground (gc, &color);
+      gdk_draw_arc (GDK_DRAWABLE(cat_display->window), gc, TRUE, i * height, 1,
+                    height - 2, height - 2, 0, 23040);
+      g_object_unref (gc);
+    }
+
+  return TRUE;
+}
+
 static GtkItemFactoryEntry popup_items[] =
 {
   { "/Edit",		    NULL, menu_do_edit,           0, "<Item>" },
@@ -1257,6 +1350,7 @@ create_main (gboolean edit_structure)
   GtkTreeSelection *tree_sel;
   GtkWidget *scrolled_window;
   GtkWidget *lStatus = NULL;
+  GtkWidget *cat_display = NULL;
   GtkTooltips *tooltips;
   gint size_x, size_y;
 
@@ -1487,8 +1581,21 @@ create_main (gboolean edit_structure)
 
   
   /** detail section **/
-  pDetail = gtk_frame_new (_("Contact"));
+  GtkWidget *framebox = gtk_hbox_new (FALSE, gpe_get_boxspacing());
+  GtkWidget *framelabel = gtk_label_new (_("Contact"));
+  cat_display = gtk_drawing_area_new ();
   
+  gtk_box_pack_start (GTK_BOX (framebox), framelabel, FALSE, TRUE, 0);
+  gtk_box_pack_end (GTK_BOX (framebox), cat_display, FALSE, FALSE, 0);
+  g_object_set_data (G_OBJECT(cat_display), "label", framelabel);
+  g_object_set_data (G_OBJECT(main_window), "cat_display", cat_display);
+  g_signal_connect (G_OBJECT (cat_display), "expose_event",  
+                    G_CALLBACK (cat_display_expose), NULL);
+
+  pDetail = gtk_frame_new (NULL);
+  gtk_frame_set_label_widget (GTK_FRAME (pDetail), framebox);
+
+
   if (mode_landscape)
     {
       gtk_container_set_border_width(GTK_CONTAINER(pDetail), gpe_get_border());
