@@ -11,6 +11,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
+#include <unistd.h>
 
 #include <gpe/pixmaps.h>
 #include <gpe/gtkdatecombo.h>
@@ -24,6 +25,8 @@
 GSList *edit_pages;
 GList *well_known_tags;
 
+#define LAYOUT_NAME "/.gpe/contacts-layout.xml"
+
 edit_thing_t new_thing (edit_thing_type t, gchar *name, edit_thing_t parent);
 
 static void
@@ -647,3 +650,20 @@ load_well_known_tags (void)
       fclose (fp);
     }
 }
+
+gboolean
+load_structure (gchar* default_structure)
+{
+  gchar *buf;
+  gboolean rc = TRUE;
+
+  buf = g_strdup_printf ("%s/%s", g_get_home_dir (), LAYOUT_NAME);
+  
+  if (access (buf, F_OK))
+    read_structure (default_structure);
+  else
+    rc = read_structure (buf);
+  
+  g_free (buf);
+  return rc;
+}
